summaryrefslogtreecommitdiffstats
path: root/src/knowit.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-30 19:20:52 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-30 19:20:52 +0000
commite86f8310a920cbf1ecfac955fbad05916e954693 (patch)
treeddc018560d03c6aa794d9f399d006e5e3aa597f0 /src/knowit.h
parent1829a84466f690d4a6a10ddab91cea0f45ec9d77 (diff)
downloadknowit-e86f8310a920cbf1ecfac955fbad05916e954693.tar.gz
knowit-e86f8310a920cbf1ecfac955fbad05916e954693.zip
TQt4 port knowit
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/knowit@1238876 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/knowit.h')
-rw-r--r--src/knowit.h53
1 files changed, 27 insertions, 26 deletions
diff --git a/src/knowit.h b/src/knowit.h
index 59c0ca7..095f6f6 100644
--- a/src/knowit.h
+++ b/src/knowit.h
@@ -22,7 +22,7 @@
#include <config.h>
#endif
-#include <qurloperator.h>
+#include <tqurloperator.h>
#include <keditcl.h>
#include <klocale.h>
@@ -34,8 +34,8 @@
#include "knowitlink.h"
#include "notes.h"
-class QSplitter;
-class QTimer;
+class TQSplitter;
+class TQTimer;
class KAction;
class KConfig;
class KListBox;
@@ -51,15 +51,16 @@ class KnowitTree;
class Knowit : public KMainWindow
{
Q_OBJECT
+ TQ_OBJECT
private:
- static const QString Untitled;
+ static const TQString Untitled;
KConfig *config;
- QSplitter* Layout;
+ TQSplitter* Layout;
KnowitTree* Items;
KListBox* Links;
KnowitEdit* Edit;
KURL filename;
- QPixmap pixmapFolder, pixmapFolderText, pixmapText, pixmapEmpty;
+ TQPixmap pixmapFolder, pixmapFolderText, pixmapText, pixmapEmpty;
KEdFind FindDlg;
KnowitOptions Options;
KnowitPreferences PrefDlg;
@@ -69,11 +70,11 @@ class Knowit : public KMainWindow
/* data items */
TNotesCollection Notes;
bool runMinimized;
- QListViewItem* lastSought;
- QString soughtText;
- QTimer* AutosaveTimer;
+ TQListViewItem* lastSought;
+ TQString soughtText;
+ TQTimer* AutosaveTimer;
/* for saving backups */
- QUrlOperator URLOperator;
+ TQUrlOperator URLOperator;
/* false by default, set to true on queryClose() */
bool shuttingDown;
/* actions */
@@ -87,7 +88,7 @@ class Knowit : public KMainWindow
enum {StatusText = 1, StatusOvr = 2};
public:
/** Constructor of main window */
- Knowit(QWidget* parent=0, const char *name=0);
+ Knowit(TQWidget* tqparent=0, const char *name=0);
/** Standard destructor */
~Knowit();
/** Opens document */
@@ -108,23 +109,23 @@ class Knowit : public KMainWindow
/** Finds and shows next occurence of currently sought text
- or show message that it couldn't be found */
- void find(QListViewItem* start = 0);
+ void tqfind(TQListViewItem* start = 0);
/** Returns true if notes or current text were modified */
bool modified();
- /** Reimplemented from QWidget to prevent from closing when docked */
- virtual void closeEvent(QCloseEvent* e);
+ /** Reimplemented from TQWidget to prevent from closing when docked */
+ virtual void closeEvent(TQCloseEvent* e);
/** Apply current configuration */
void applyOptions(const KnowitOptions& O, bool store = true);
/** Returns current note */
TNote* currentNote() const;
public slots:
- /** Status bar text has changed - displays it */
- void slotStatusMsg(const QString& text);
+ /** tqStatus bar text has changed - displays it */
+ void slotStatusMsg(const TQString& text);
/** Shows requested popup menu for notes */
- void slotContextMenu(KListView*, QListViewItem*, const QPoint&);
+ void slotContextMenu(KListView*, TQListViewItem*, const TQPoint&);
/** Shows given note */
- void slotNoteChanged(QListViewItem* item);
+ void slotNoteChanged(TQListViewItem* item);
/** Add same-level note */
void slotNoteAdd();
/** Adds subnote */
@@ -150,7 +151,7 @@ class Knowit : public KMainWindow
void slotNoteMoveRight();
/** Current item has changed - updates associated text and shows next */
- void slotItemChanged(QListViewItem*);
+ void slotItemChanged(TQListViewItem*);
/** Resets to a new file */
void slotFileNew();
/** Prompts for a file to open and opens it */
@@ -179,11 +180,11 @@ class Knowit : public KMainWindow
void slotEditUnderline();
/** Changes color of selected/current text */
void slotEditColor();
- /** Changes vertical alignment to superscript */
+ /** Changes vertical tqalignment to superscript */
void slotEditSuperscript();
- /** Changes vertical alignment to subscript */
+ /** Changes vertical tqalignment to subscript */
void slotEditSubscript();
- /** Restores normal vertical alignment */
+ /** Restores normal vertical tqalignment */
void slotEditNormal();
/** Prompts for text and shows note containing it */
void slotEditFind();
@@ -199,7 +200,7 @@ class Knowit : public KMainWindow
void slotEditAlignJustify();
/** Centers text */
void slotEditAlignCenter();
- /** Change selected paragraphs to list. Warning: uses obsolete Qt function */
+ /** Change selected paragraphs to list. Warning: uses obsolete TQt function */
void slotEditListBullet();
void slotEditListNumber();
void slotEditListUpper();
@@ -235,13 +236,13 @@ class Knowit : public KMainWindow
void slotRawTextMode();
/** Shows requested popup menu for links */
- void slotContextLinksMenu(QListBoxItem* item, const QPoint&);
+ void slotContextLinksMenu(TQListBoxItem* item, const TQPoint&);
/** show current attachment **/
- void slotShowAttachment(QListBoxItem* i);
+ void slotShowAttachment(TQListBoxItem* i);
/** Add link **/
void slotLinkAdd();
/** Handle dropped link **/
- void slotLinkDropped(const QString& s, int flags);
+ void slotLinkDropped(const TQString& s, int flags);
/** Remove link **/
void slotLinkRemove();
/** Open link **/